import React, { useCallback, useEffect, useState } from 'react';
import { Pressable, VirtualizedList } from 'react-native';
import { useNodesContext } from '../nodes-context-provider';
const NodeView = React.memo(({ renderNode, extraData, level, getChildrenName, node, onNodePressed, keepOpenedState, initialNumToRender, }) => {
    const { openedNodes, setOpenNode } = useNodesContext();
    const [_node, setNode] = useState(Object.assign(Object.assign({}, node), { opened: keepOpenedState && openedNodes[node._internalId]
            ? !!openedNodes[node._internalId]
            : !!node.opened }));
    useEffect(() => {
        setNode(Object.assign(Object.assign({}, node), { opened: _node.opened }));
    }, [node, _node.opened]);
    const _onNodePressed = useCallback(() => {
        if (keepOpenedState) {
            setOpenNode({
                internalId: _node._internalId,
                opened: !_node.opened,
            });
        }
        setNode(Object.assign(Object.assign({}, _node), { opened: !_node.opened }));
        if (onNodePressed) {
            onNodePressed(_node);
        }
    }, [_node, keepOpenedState, onNodePressed, setOpenNode]);
    const renderChildren = useCallback((item, _level) => (<NodeView getChildrenName={getChildrenName} node={item} level={_level + 1} extraData={extraData} onNodePressed={onNodePressed} renderNode={renderNode} keepOpenedState={keepOpenedState}/>), [extraData, getChildrenName, onNodePressed, renderNode, keepOpenedState]);
    const renderItem = useCallback(({ item }) => renderChildren(item, level), [renderChildren, level]);
    const getItem = useCallback((data, index) => data && data[index], []);
    const getItemCount = useCallback((data) => { var _a; return (_a = data === null || data === void 0 ? void 0 : data.length) !== null && _a !== void 0 ? _a : 0; }, []);
    const keyExtractor = useCallback((item) => item._internalId, []);
    const nodeChildrenName = getChildrenName(_node);
    const nodeChildren = _node[nodeChildrenName];
    const isNodeOpened = (keepOpenedState && openedNodes[node._internalId]) || _node.opened;
    return (<>
        {!_node.hidden ? (<Pressable onPress={_onNodePressed}>
            {renderNode(_node, level, !nodeChildren || !nodeChildren.length)}
          </Pressable>) : null}
        {isNodeOpened && nodeChildren ? (<VirtualizedList data={nodeChildren} getItemCount={getItemCount} getItem={getItem} renderItem={renderItem} extraData={extraData} keyExtractor={keyExtractor} listKey={node._internalId} initialNumToRender={initialNumToRender}/>) : null}
      </>);
});
NodeView.displayName = 'NodeView';
export { NodeView };
//# sourceMappingURL=node-view.js.map